Crate s_test_fixture[−][src]
s_test_fixture
s_test_fixture or simple test fixture is a macro library to implement test fixture with no hassle.
Their is four macros: before, after, before_each, after_each. The function pass as argument must return nothing.
before and after are added before the target test function . before_each and after_each are added before the target module.
Attribute Macros
execute a function after the test is executed even if the test failled
for each tests of a module execute the function after the test end even if the test failled
execute a function before the test start
for each tests of a module execute the function before the test start